# 👸 BELA

**B**LIP  **E**LAN  **L**anguage **A**nnotation - A method for creating and processing multi-lingual transcriptions using [BELA convention](https://blipntu.github.io/belacon/) and [ELAN software](https://archive.mpi.nl/tla/elan/download).

- Documentation: [https://blipntu.github.io/belacon/](https://blipntu.github.io/belacon/)
- Source code: [https://github.com/letuananh/bela](https://github.com/letuananh/bela)
- PyPI: [https://pypi.org/project/bela/](https://pypi.org/project/bela/)

## Installation

**BELA** is available on [PyPI](https://pypi.org/project/bela/) and can be installed using pip:

```
pip install bela
```

## Citation

Tuan Anh Le, Seraphina Fong, Jinyi Wong,
Fei Ting Woon, Eshwaaree C Yogarrajah, Nur Sakinah Binte Mohd Salleh, Shaza binte Amran,
Suzy J Styles, 2021,
*"BELA - A Processing Pathway for Multilingual Parent-child Conversations"*,
[BMRS 2021](https://www.bilingualism-matters.org/events/bilingualism-matters-research-symposium-2021)

## License

**BELA** package is licensed under MIT License.
